# winsay
[![PyPI](https://img.shields.io/pypi/v/winsay.svg)](https://pypi.org/project/winsay/)
[![Changelog](https://img.shields.io/github/v/release/sukhbinder/winsay?include_prereleases&label=changelog)](https://github.com/sukhbinder/winsay/releases)
[![Tests](https://github.com/sukhbinder/winsay/workflows/Test/badge.svg)](https://github.com/sukhbinder/winsay/actions?query=workflow%3ATest)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/sukhbinder/winsay/blob/main/LICENSE)

Say command in windows

```
say -h
usage: say [-h] [-i INPUT] [text [text ...]]

Say in windows

positional arguments:
  text                  sentence to speak

optional arguments:
  -h, --help            show this help message and exit
  -i INPUT, --input INPUT
                        Text File to speak
```


### Back Story

Read the backstory for this project [here](https://sukhbinder.wordpress.com/2020/09/30/winsay/)

# Install
pip install winsay


# Demo

[![Check a demo](https://raw.githubusercontent.com/sukhbinder/winsay/master/img/youtube.png)](https://youtu.be/dZaV5MtG3n4)


